@@ -1,5 +1,6 @@
 """Rich text and beautiful formatting in the terminal."""
 
+import os
 from typing import Any, IO, Optional, TYPE_CHECKING
 
 __all__ = ["get_console", "reconfigure", "print", "inspect"]
@@ -10,6 +11,8 @@ if TYPE_CHECKING:
 # Global console used by alternative print
 _console: Optional["Console"] = None
 
+_IMPORT_CWD = os.path.abspath(os.getcwd())
+
 
 def get_console() -> "Console":
     """Get a global :class:`~rich.console.Console` instance. This function is used when Rich requires a Console,
@@ -27,8 +30,8 @@ def get_console() -> "Console":
     return _console
 
 
-def reconfigure(*args, **kwargs) -> None:
-    """Reconfigures the global console bu replacing it with another.
+def reconfigure(*args: Any, **kwargs: Any) -> None:
+    """Reconfigures the global console by replacing it with another.
 
     Args:
         console (Console): Replacement console instance.
@@ -39,7 +42,13 @@ def reconfigure(*args, **kwargs) -> None:
     _console.__dict__ = new_console.__dict__
 
 
-def print(*objects: Any, sep=" ", end="\n", file: IO[str] = None, flush: bool = False):
+def print(
+    *objects: Any,
+    sep: str = " ",
+    end: str = "\n",
+    file: Optional[IO[str]] = None,
+    flush: bool = False
+) -> None:
     r"""Print object(s) supplied via positional arguments.
     This function has an identical signature to the built-in print.
     For more advanced features, see the :class:`~rich.console.Console` class.
@@ -60,8 +69,8 @@ def print(*objects: Any, sep=" ", end="\n", file: IO[str] = None, flush: bool =
 def inspect(
     obj: Any,
     *,
-    console: "Console" = None,
-    title: str = None,
+    console: Optional["Console"] = None,
+    title: Optional[str] = None,
     help: bool = False,
     methods: bool = False,
     docs: bool = True,
@@ -70,7 +79,7 @@ def inspect(
     sort: bool = True,
     all: bool = False,
     value: bool = True
-):
+) -> None:
     """Inspect any Python object.
 
     * inspect(<OBJECT>) to see summarized info.
