@@ -93,22 +93,22 @@ class Style:
     def __init__(
         self,
         *,
-        color: Union[Color, str] = None,
-        bgcolor: Union[Color, str] = None,
-        bold: bool = None,
-        dim: bool = None,
-        italic: bool = None,
-        underline: bool = None,
-        blink: bool = None,
-        blink2: bool = None,
-        reverse: bool = None,
-        conceal: bool = None,
-        strike: bool = None,
-        underline2: bool = None,
-        frame: bool = None,
-        encircle: bool = None,
-        overline: bool = None,
-        link: str = None,
+        color: Optional[Union[Color, str]] = None,
+        bgcolor: Optional[Union[Color, str]] = None,
+        bold: Optional[bool] = None,
+        dim: Optional[bool] = None,
+        italic: Optional[bool] = None,
+        underline: Optional[bool] = None,
+        blink: Optional[bool] = None,
+        blink2: Optional[bool] = None,
+        reverse: Optional[bool] = None,
+        conceal: Optional[bool] = None,
+        strike: Optional[bool] = None,
+        underline2: Optional[bool] = None,
+        frame: Optional[bool] = None,
+        encircle: Optional[bool] = None,
+        overline: Optional[bool] = None,
+        link: Optional[str] = None,
     ):
         self._ansi: Optional[str] = None
         self._style_definition: Optional[str] = None
@@ -176,14 +176,16 @@ class Style:
         return NULL_STYLE
 
     @classmethod
-    def from_color(cls, color: Color = None, bgcolor: Color = None) -> "Style":
+    def from_color(
+        cls, color: Optional[Color] = None, bgcolor: Optional[Color] = None
+    ) -> "Style":
         """Create a new style with colors and no attributes.
 
         Returns:
             color (Optional[Color]): A (foreground) color, or None for no color. Defaults to None.
             bgcolor (Optional[Color]): A (background) color, or None for no color. Defaults to None.
         """
-        style = cls.__new__(Style)
+        style: Style = cls.__new__(Style)
         style._ansi = None
         style._style_definition = None
         style._color = color
@@ -383,6 +385,24 @@ class Style:
         """A Style with background only."""
         return Style(bgcolor=self.bgcolor)
 
+    @property
+    def without_color(self) -> "Style":
+        """Get a copy of the style with color removed."""
+        if self._null:
+            return NULL_STYLE
+        style: Style = self.__new__(Style)
+        style._ansi = None
+        style._style_definition = None
+        style._color = None
+        style._bgcolor = None
+        style._attributes = self._attributes
+        style._set_attributes = self._set_attributes
+        style._link = self._link
+        style._link_id = f"{time()}-{randint(0, 999999)}" if self._link else ""
+        style._hash = self._hash
+        style._null = False
+        return style
+
     @classmethod
     @lru_cache(maxsize=4096)
     def parse(cls, style_definition: str) -> "Style":
@@ -397,7 +417,7 @@ class Style:
         Returns:
             `Style`: A Style instance.
         """
-        if style_definition.strip() == "none":
+        if style_definition.strip() == "none" or not style_definition:
             return cls.null()
 
         style_attributes = {
@@ -474,7 +494,7 @@ class Style:
         return style
 
     @lru_cache(maxsize=1024)
-    def get_html_style(self, theme: TerminalTheme = None) -> str:
+    def get_html_style(self, theme: Optional[TerminalTheme] = None) -> str:
         """Get a CSS style rule."""
         theme = theme or DEFAULT_TERMINAL_THEME
         css: List[str] = []
@@ -494,6 +514,7 @@ class Style:
         if color is not None:
             theme_color = color.get_truecolor(theme)
             append(f"color: {theme_color.hex}")
+            append(f"text-decoration-color: {theme_color.hex}")
         if bgcolor is not None:
             theme_color = bgcolor.get_truecolor(theme, foreground=False)
             append(f"background-color: {theme_color.hex}")
@@ -543,7 +564,7 @@ class Style:
         """
         if self._null:
             return NULL_STYLE
-        style = self.__new__(Style)
+        style: Style = self.__new__(Style)
         style._ansi = self._ansi
         style._style_definition = self._style_definition
         style._color = self._color
@@ -556,7 +577,7 @@ class Style:
         style._null = False
         return style
 
-    def update_link(self, link: str = None) -> "Style":
+    def update_link(self, link: Optional[str] = None) -> "Style":
         """Get a copy with a different value for link.
 
         Args:
@@ -565,7 +586,7 @@ class Style:
         Returns:
             Style: A new Style instance.
         """
-        style = self.__new__(Style)
+        style: Style = self.__new__(Style)
         style._ansi = self._ansi
         style._style_definition = self._style_definition
         style._color = self._color
@@ -618,12 +639,12 @@ class Style:
 
     def __add__(self, style: Optional["Style"]) -> "Style":
         if not (isinstance(style, Style) or style is None):
-            return NotImplemented  # type: ignore
+            return NotImplemented
         if style is None or style._null:
             return self
         if self._null:
             return style
-        new_style = self.__new__(Style)
+        new_style: Style = self.__new__(Style)
         new_style._ansi = None
         new_style._style_definition = None
         new_style._color = style._color or self._color
